Inori - The Universal API Client Constructor
============================================

.. image:: https://img.shields.io/pypi/v/inori.svg
    :target: https://pypi.org/project/inori
    :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/inori.svg
    :alt: PyPI - Python Version
    :target: https://github.com/jsfehler/inori

.. image:: https://img.shields.io/github/license/jsfehler/inori.svg
    :alt: GitHub
    :target: https://github.com/jsfehler/inori/blob/master/LICENSE
